A                 { text-decoration: none; }
A.banner          { color  : #FFFFFF;
                    font-size : small;
                    text-decoration : none;
                  }
A.bblue           { color: #FFFFFF;
                    background-color: #9999FF;
                    font-size : small;
                    text-align: center;
                  }
A.bred            { color: #FFFFFF;
                    background-color: #FF6666;
                    font-size : small;
                    text-align: center;
                  }
BODY              { background-color: white; 
                    font-family: sans-serif;
                  }
H1                { color: #3366FF; 
                    font-family: sans-serif; 
                  }
H2                { color: #3366FF; 
                    font-family: sans-serif; 
                  }
H3                { color: #3366FF; 
                    font-family: sans-serif; 
                  }
H4                { color: #3366FF; 
                    font-family: sans-serif; 
                  }
INPUT             { background-color: white; }
OL                { font-family: sans-serif; }
UL                { font-family: sans-serif; }
LI                { font-family: sans-serif; 
                    list-style: url(/images/reddot.jpg) outside;
                  }
DL                { font-family: sans-serif; }
DT                { font-family: sans-serif; }
DD                { font-family: sans-serif; }

LI.new            { font-family: sans-serif; 
                    list-style: url(/icons/new.gif)     outside;
                  }
P                 { font-family: sans-serif; }
PRE.peptide       { font-size: small; }
PRE.dna           { font-size: small; 
                    font-family: monospace;
                  }
SELECT            { background-color: white; }
TABLE             { padding: 0;
                    spacing: 2;
                    width: 100%;
                  }
TD                { font-family: sans-serif; }
TH                { font-family: sans-serif; 
                    padding: 0; 
                  }
.abstract         { background-color: #FFEEEE; }
.acetree          { font-size: 10pt; }
.banner           { font-size: x-large;
                    align: center;
                    background-color: blue;
                    color: yellow;
                    padding: 100px 3px;
                  }
.databody         { background-color: #FFFFCC; }
.databodysmall    { background-color: #FFFFCC; }
.datatitle        { background-color: #FFFF99; }
.description      { font-style: italic; }
.error            { color: red; }
.exon             { background-color: #00FFFF;
                    color: #000000;
                  }
.exonalt          { background-color: #EEEE99; 
                    color: #000000;
                  }
.exonm            { /* font-weight: bold; */
	            background-color: #00FFFF; 
                    color: #000000;
                  }
.flankm           { background-color: #FFFFFF; 
                    color: #888888;
                  }
.match            { background-color: #FFFF77;
                    color: #FF00;
                  }
.gene             { font-style: italic; }
.highlight        { background-color: #f5deb3; }
.intron           { background-color: #FFFFFF; 
                    color: #000000;
                  }
.intronm          { background-color: #FFFFFF; 
                    color: #000000;
                  }
.mism             { color: #000000;
                    background-color: #FF9999;
                  }
.note             { color: red; }
.phenotype        { font-style: italic;
                    margin-left: 2em;
                  }
.pre              { font-family: monospace; }
.resultsbody      { background-color: #CCFFFF; }
.resultsbodyalt   { background-color: #EEFFFF; }
.resultstitle     { background-color: #93cbf4; }
.search           { font-size: small; }
.searchbody       { background-color: #FFFFCC; }
.searchbodyalt    { background-color: #CCFFFF; }
.searchtitle      { background-color: #FFFF99; }
.small            { font-size: small; }
.smalldescription { font-style: italic;
                    font-size: small;
                  }
.technicalinfo    { background-color: #FFFFFF; }
.toggle           { color: #3366FF; }
.transcriptf      { fillcolor: white;
                    color: black;
                    curatedexon: slateblue;
                    fontcolor: slateblue;
                    bump: -1;
                    height: 10;
                  }
.transcriptr      { fillcolor: white;
                    curatedexon: dodgerblue;
                    fontcolor: dodgerblue;
                    color: black;
                    bump: +1;
                    height: 10;
                  }
.BLAT             { fillcolor: greenyellow;
                    color: black;
                    bump: +1;
                    height: 4;
                    connectgroups: 1;
                    connector: black;
                    key: 'ESTs\ aligned\ by\ BLAT';
                  }
.EST_GENOME       { fillcolor: limegreen;
                    color: black;
                    bump: +1;
                    height: 4;
                    stranded: 1;
                    connectgroups: 1;
                    connector: black;
                    key: 'ESTs\ aligned\ by\ EST_GENOME';
                  }
.RNAi             { fillcolor: goldenrod;
                    color: black;
                    height: 4;
                    bump: +1;
                    key: 'RNAi\ experiments';
                  }
.oligo            { fillcolor: violet;
                    color: black;
                    connect: 1
                    connector: violet;
                    bump: -1
                    key: 'oligos';
                  }
.briggsae         { fillcolor: tomato;
                    color: black;
                    height: 4;
                    bump: +1;
                    key: 'C.\ briggsae\ similarity';
                  }
.misc_feature     { fillcolor: bisque;
                    color: black;
                    height: 4;
                    bump: +1;
                    key: 'Miscellaneous';
                  }
.clone            { color: black;
                    height: 7;
                    bump: +1;
                    key: 'YACs\ &\ Cosmids';
                  }
